Composition rendering - layering sprites onto a canvas
Structs
- Render
Context - Context for rendering operations with caching support.
- Warning
- A warning generated during composition rendering
Enums
- Blend
Mode - Blend modes for composition layers
- Composition
Error - Error when rendering a composition in strict mode.
Functions
- render_
composition - Render a composition to an RGBA image buffer.
- render_
composition_ nested - Render a composition with support for nested composition references (NC-4).
- resolve_
blend_ mode - Resolve a blend mode string, potentially containing a var() reference.
- resolve_
opacity - Resolve an opacity value, potentially containing a var() reference.