pub fn resolve_blend_mode(
blend: Option<&str>,
registry: Option<&VariableRegistry>,
) -> (BlendMode, Option<Warning>)Expand description
Resolve a blend mode string, potentially containing a var() reference.
Returns the resolved blend mode and any warning if resolution failed.