Module loader

Module loader 

Configuration loading and discovery for pxl.toml

Provides functions to find, load, and merge configuration.

Structs

CliOverrides
CLI arguments that can override config values

Enums

ConfigError
Configuration loading error

Functions

default_config
Create a default configuration when no pxl.toml is found.
find_config
Find pxl.toml by walking up from the current working directory.
find_config_from
Find pxl.toml by walking up from a specific directory.
load_config
Load configuration from a pxl.toml file.
merge_cli_overrides
Merge CLI overrides into a configuration.
project_root
Get the project root directory from a config file path.
resolve_path
Resolve a path relative to the project root.