Configuration loading and discovery for pxl.toml
Provides functions to find, load, and merge configuration.
Structs
- CliOverrides
- CLI arguments that can override config values
Enums
- Config
Error - Configuration loading error
Functions
- default_
config - Create a default configuration when no pxl.toml is found.
- find_
config - Find pxl.toml by walking up from the current working directory.
- find_
config_ from - Find pxl.toml by walking up from a specific directory.
- load_
config - Load configuration from a pxl.toml file.
- merge_
cli_ overrides - Merge CLI overrides into a configuration.
- project_
root - Get the project root directory from a config file path.
- resolve_
path - Resolve a path relative to the project root.